==> cxf-testutils-2.0.6.14-fuse-sources.jar: org/apache/type_test/xml/TestRecursiveStructArrayResponse.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.RecursiveStructArray;


/**
 * <p>Java class for testRecursiveStructArrayResponse element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testRecursiveStructArrayResponse">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="return" type="{http://apache.org/type_test/types1}RecursiveStructArray"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types1}RecursiveStructArray"/>
 *           &lt;element name="z" type="{http://apache.org/type_test/types1}RecursiveStructArray"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_return",
    "y",
    "z"
})
@XmlRootElement(name = "testRecursiveStructArrayResponse")
public class TestRecursiveStructArrayResponse {

    @XmlElement(name = "return", namespace = "http://apache.org/type_test/xml", required = true)
    protected RecursiveStructArray _return;
    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected RecursiveStructArray y;
    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected RecursiveStructArray z;

    /**
     * Gets the value of the return property.
     * 
     * @return
     *     possible object is
     *     {@link RecursiveStructArray }
     *     
     */
    public RecursiveStructArray getReturn() {
        return _return;
    }

    /**
     * Sets the value of the return property.
     * 
     * @param value
     *     allowed object is
     *     {@link RecursiveStructArray }
     *     
     */
    public void setReturn(RecursiveStructArray value) {
        this._return = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link RecursiveStructArray }
     *     
     */
    public RecursiveStructArray getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link RecursiveStructArray }
     *     
     */
    public void setY(RecursiveStructArray value) {
        this.y = value;
    }

    /**
     * Gets the value of the z property.
     * 
     * @return
     *     possible object is
     *     {@link RecursiveStructArray }
     *     
     */
    public RecursiveStructArray getZ() {
        return z;
    }

    /**
     * Sets the value of the z property.
     * 
     * @param value
     *     allowed object is
     *     {@link RecursiveStructArray }
     *     
     */
    public void setZ(RecursiveStructArray value) {
        this.z = value;
    }

}

==> cxf-testutils-2.1.3.18-fuse-sources.jar: org/apache/type_test/xml/TestRecursiveStructArrayResponse.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.RecursiveStructArray;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="return" type="{http://apache.org/type_test/types1}RecursiveStructArray"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types1}RecursiveStructArray"/>
 *         &lt;element name="z" type="{http://apache.org/type_test/types1}RecursiveStructArray"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_return",
    "y",
    "z"
})
@XmlRootElement(name = "testRecursiveStructArrayResponse")
public class TestRecursiveStructArrayResponse {

    @XmlElement(name = "return", required = true)
    protected RecursiveStructArray _return;
    @XmlElement(required = true)
    protected RecursiveStructArray y;
    @XmlElement(required = true)
    protected RecursiveStructArray z;

    /**
     * Gets the value of the return property.
     * 
     * @return
     *     possible object is
     *     {@link RecursiveStructArray }
     *     
     */
    public RecursiveStructArray getReturn() {
        return _return;
    }

    /**
     * Sets the value of the return property.
     * 
     * @param value
     *     allowed object is
     *     {@link RecursiveStructArray }
     *     
     */
    public void setReturn(RecursiveStructArray value) {
        this._return = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link RecursiveStructArray }
     *     
     */
    public RecursiveStructArray getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link RecursiveStructArray }
     *     
     */
    public void setY(RecursiveStructArray value) {
        this.y = value;
    }

    /**
     * Gets the value of the z property.
     * 
     * @return
     *     possible object is
     *     {@link RecursiveStructArray }
     *     
     */
    public RecursiveStructArray getZ() {
        return z;
    }

    /**
     * Sets the value of the z property.
     * 
     * @param value
     *     allowed object is
     *     {@link RecursiveStructArray }
     *     
     */
    public void setZ(RecursiveStructArray value) {
        this.z = value;
    }

}
